@@ -4,7 +4,7 @@ use strict;
 use warnings;
 no strict 'refs';
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 use Carp;
 use Exporter;
@@ -13,7 +13,7 @@ require XSLoader;
 XSLoader::load('URI::Fast', $VERSION);
 
 use Exporter 'import';
-our @EXPORT_OK = qw(uri iri uri_split);
+our @EXPORT_OK = qw(uri iri uri_split encode decode);
 
 use overload '""' => sub{ $_[0]->to_string };
 
@@ -157,6 +157,8 @@ parameter.
 
 =head1 EXPORTED SUBROUTINES
 
+Subroutines are exported on demand.
+
 =head2 uri
 
 Accepts a URI string, minimally parses it, and returns a C<URI::Fast> object.
@@ -171,6 +173,10 @@ be percent-encoded when modified.
 
 Behaves (hopefully) identically to L<URI::Split>, but roughly twice as fast.
 
+=head2 encode/decode
+
+See L</ENCODING>.
+
 =head1 ATTRIBUTES
 
 Unless otherwise specified, all attributes serve as full accessors, allowing
